# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: duckdb_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'duckdb_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x64uckdb_service.proto\x12\nisa.duckdb\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x96\x03\n\x0c\x44\x61tabaseInfo\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12\x14\n\x0cminio_bucket\x18\x05 \x01(\t\x12\x12\n\nminio_path\x18\x06 \x01(\t\x12\x12\n\nsize_bytes\x18\x07 \x01(\x03\x12\x13\n\x0btable_count\x18\x08 \x01(\x05\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rlast_accessed\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x08metadata\x18\x0b \x03(\x0b\x32&.isa.duckdb.DatabaseInfo.MetadataEntry\x12\x0f\n\x07version\x18\x0c \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd9\x01\n\tTableInfo\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x13\n\x0bschema_name\x18\x02 \x01(\t\x12\'\n\x07\x63olumns\x18\x03 \x03(\x0b\x32\x16.isa.duckdb.ColumnInfo\x12\x11\n\trow_count\x18\x04 \x01(\x03\x12\x12\n\nsize_bytes\x18\x05 \x01(\x03\x12\x12\n\ntable_type\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63omment\x18\x08 \x01(\t\"\x92\x01\n\nColumnInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x10\n\x08nullable\x18\x03 \x01(\x08\x12\x15\n\rdefault_value\x18\x04 \x01(\t\x12\x16\n\x0eis_primary_key\x18\x05 \x01(\x08\x12\x11\n\tis_unique\x18\x06 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x07 \x01(\t\"\xa4\x01\n\x10QueryResultChunk\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x14\n\x0c\x63olumn_types\x18\x03 \x03(\t\x12\x1d\n\x04rows\x18\x04 \x03(\x0b\x32\x0f.isa.duckdb.Row\x12\x0f\n\x07is_last\x18\x05 \x01(\x08\x12\x19\n\x11\x65xecution_time_ms\x18\x06 \x01(\x01\x12\r\n\x05\x65rror\x18\x07 \x01(\t\"(\n\x03Row\x12!\n\x06values\x18\x01 \x03(\x0b\x32\x11.isa.duckdb.Value\"\x97\x02\n\x05Value\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x15\n\x0b\x62ytes_value\x18\x05 \x01(\x0cH\x00\x12\x35\n\x0ftimestamp_value\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12/\n\x0cstruct_value\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12+\n\nnull_value\x18\x08 \x01(\x0e\x32\x15.isa.duckdb.NullValueH\x00\x42\x07\n\x05value\"v\n\nTableStats\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x11\n\trow_count\x18\x02 \x01(\x03\x12\x12\n\nsize_bytes\x18\x03 \x01(\x03\x12-\n\x0c\x63olumn_stats\x18\x04 \x03(\x0b\x32\x17.isa.duckdb.ColumnStats\"\x9a\x01\n\x0b\x43olumnStats\x12\x13\n\x0b\x63olumn_name\x18\x01 \x01(\t\x12\x16\n\x0e\x64istinct_count\x18\x02 \x01(\x03\x12$\n\tmin_value\x18\x03 \x01(\x0b\x32\x11.isa.duckdb.Value\x12$\n\tmax_value\x18\x04 \x01(\x0b\x32\x11.isa.duckdb.Value\x12\x12\n\nnull_count\x18\x05 \x01(\x03\"\xd0\x02\n\x15\x43reateDatabaseRequest\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x14\n\x0cminio_bucket\x18\x04 \x01(\t\x12\x41\n\x08metadata\x18\x05 \x03(\x0b\x32/.isa.duckdb.CreateDatabaseRequest.MetadataEntry\x12=\n\x06\x63onfig\x18\x06 \x03(\x0b\x32-.isa.duckdb.CreateDatabaseRequest.ConfigEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0b\x43onfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x16\x43reateDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\rdatabase_info\x18\x03 \x01(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"v\n\x14ListDatabasesRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x13\n\x0bname_filter\x18\x03 \x01(\t\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x11\n\tpage_size\x18\x05 \x01(\x05\"\x9a\x01\n\x15ListDatabasesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12+\n\tdatabases\x18\x02 \x03(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\x12\x0c\n\x04page\x18\x04 \x01(\x05\x12\x11\n\tpage_size\x18\x05 \x01(\x05\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"g\n\x15\x44\x65leteDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x19\n\x11\x64\x65lete_from_minio\x18\x03 \x01(\x08\x12\r\n\x05\x66orce\x18\x04 \x01(\x08\"I\n\x16\x44\x65leteDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\">\n\x16GetDatabaseInfoRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"j\n\x17GetDatabaseInfoResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12/\n\rdatabase_info\x18\x02 \x01(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"g\n\x15\x42\x61\x63kupDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61\x63kup_name\x18\x03 \x01(\t\x12\x13\n\x0bincremental\x18\x04 \x01(\x08\"\xa4\x01\n\x16\x42\x61\x63kupDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61\x63kup_path\x18\x03 \x01(\t\x12\x13\n\x0b\x62\x61\x63kup_size\x18\x04 \x01(\x03\x12/\n\x0b\x62\x61\x63kup_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"Y\n\x16RestoreDatabaseRequest\x12\x13\n\x0b\x62\x61\x63kup_path\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x19\n\x11new_database_name\x18\x03 \x01(\t\"{\n\x17RestoreDatabaseResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12/\n\rdatabase_info\x18\x03 \x01(\x0b\x32\x18.isa.duckdb.DatabaseInfo\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\x91\x02\n\x13\x45xecuteQueryRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x43\n\nparameters\x18\x04 \x03(\x0b\x32/.isa.duckdb.ExecuteQueryRequest.ParametersEntry\x12\x10\n\x08max_rows\x18\x05 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x06 \x01(\x05\x12\x0f\n\x07\x65xplain\x18\x07 \x01(\x08\x1a\x44\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.isa.duckdb.Value:\x02\x38\x01\"\xbe\x01\n\x14\x45xecuteQueryResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x14\n\x0c\x63olumn_types\x18\x03 \x03(\t\x12\x1d\n\x04rows\x18\x04 \x03(\x0b\x32\x0f.isa.duckdb.Row\x12\x11\n\trow_count\x18\x05 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x06 \x01(\x01\x12\x12\n\nquery_plan\x18\x07 \x01(\t\x12\r\n\x05\x65rror\x18\x08 \x01(\t\"\xe1\x01\n\x17\x45xecuteStatementRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tstatement\x18\x03 \x01(\t\x12G\n\nparameters\x18\x04 \x03(\x0b\x32\x33.isa.duckdb.ExecuteStatementRequest.ParametersEntry\x1a\x44\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.isa.duckdb.Value:\x02\x38\x01\"}\n\x18\x45xecuteStatementResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\raffected_rows\x18\x02 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x03 \x01(\x01\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"d\n\x13\x45xecuteBatchRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\nstatements\x18\x03 \x03(\t\x12\x13\n\x0btransaction\x18\x04 \x01(\x08\"\x81\x01\n\x14\x45xecuteBatchResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12(\n\x07results\x18\x02 \x03(\x0b\x32\x17.isa.duckdb.BatchResult\x12\x1f\n\x17total_execution_time_ms\x18\x03 \x01(\x01\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"D\n\x0b\x42\x61tchResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\raffected_rows\x18\x02 \x01(\x05\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"R\n\x17PrepareStatementRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tstatement\x18\x03 \x01(\t\"i\n\x18PrepareStatementResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\x12\x17\n\x0fparameter_types\x18\x03 \x03(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\xb5\x01\n\x12\x43reateTableRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\'\n\x07\x63olumns\x18\x04 \x03(\x0b\x32\x16.isa.duckdb.ColumnInfo\x12\x14\n\x0cprimary_keys\x18\x05 \x03(\t\x12\x15\n\rif_not_exists\x18\x06 \x01(\x08\x12\x0f\n\x07\x63omment\x18\x07 \x01(\t\"q\n\x13\x43reateTableResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12)\n\ntable_info\x18\x03 \x01(\x0b\x32\x15.isa.duckdb.TableInfo\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"c\n\x11ListTablesRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x13\n\x0bschema_name\x18\x03 \x01(\t\x12\x13\n\x0bname_filter\x18\x04 \x01(\t\"p\n\x12ListTablesResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12%\n\x06tables\x18\x02 \x03(\x0b\x32\x15.isa.duckdb.TableInfo\x12\x13\n\x0btotal_count\x18\x03 \x01(\x05\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"p\n\x10\x44ropTableRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x11\n\tif_exists\x18\x04 \x01(\x08\x12\x0f\n\x07\x63\x61scade\x18\x05 \x01(\x08\"D\n\x11\x44ropTableResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"Q\n\x15GetTableSchemaRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\"c\n\x16GetTableSchemaResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12)\n\ntable_info\x18\x02 \x01(\x0b\x32\x15.isa.duckdb.TableInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"i\n\x14GetTableStatsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x17\n\x0finclude_columns\x18\x04 \x01(\x08\"^\n\x15GetTableStatsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12%\n\x05stats\x18\x02 \x01(\x0b\x32\x16.isa.duckdb.TableStats\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"l\n\x11\x43reateViewRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tview_name\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x0f\n\x07replace\x18\x05 \x01(\x08\"E\n\x12\x43reateViewResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"8\n\x10ListViewsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"B\n\x11ListViewsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05views\x18\x02 \x03(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"J\n\x0f\x44ropViewRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tview_name\x18\x03 \x01(\t\"C\n\x10\x44ropViewResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xa5\x02\n\x16ImportFromMinIORequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x12\n\nobject_key\x18\x05 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\t\x12\x14\n\x0c\x63reate_table\x18\x07 \x01(\x08\x12\x10\n\x08truncate\x18\x08 \x01(\x08\x12@\n\x07options\x18\t \x03(\x0b\x32/.isa.duckdb.ImportFromMinIORequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x17ImportFromMinIOResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrows_imported\x18\x03 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x04 \x01(\x01\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"\x87\x02\n\x14\x45xportToMinIORequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x04 \x01(\t\x12\x12\n\nobject_key\x18\x05 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\t\x12>\n\x07options\x18\x07 \x03(\x0b\x32-.isa.duckdb.ExportToMinIORequest.OptionsEntry\x12\x11\n\toverwrite\x18\x08 \x01(\x08\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x15\x45xportToMinIOResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrows_exported\x18\x03 \x01(\x05\x12\x11\n\tfile_size\x18\x04 \x01(\x03\x12\x19\n\x11\x65xecution_time_ms\x18\x05 \x01(\x01\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"\xf6\x01\n\x15QueryMinIOFileRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x13\n\x0b\x62ucket_name\x18\x03 \x01(\t\x12\x12\n\nobject_key\x18\x04 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x05 \x01(\t\x12\r\n\x05query\x18\x06 \x01(\t\x12?\n\x07options\x18\x07 \x03(\x0b\x32..isa.duckdb.QueryMinIOFileRequest.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\x16QueryMinIOFileResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x12\x1d\n\x04rows\x18\x03 \x03(\x0b\x32\x0f.isa.duckdb.Row\x12\x11\n\trow_count\x18\x04 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x05 \x01(\x01\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"`\n\x11ImportDataRequest\x12\x32\n\x08metadata\x18\x01 \x01(\x0b\x32\x1e.isa.duckdb.ImportDataMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\x06\n\x04\x64\x61ta\"\xe0\x01\n\x12ImportDataMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\x12\x12\n\ntotal_size\x18\x05 \x01(\x03\x12<\n\x07options\x18\x06 \x03(\x0b\x32+.isa.duckdb.ImportDataMetadata.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x12ImportDataResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\rrows_imported\x18\x03 \x01(\x05\x12\x19\n\x11\x65xecution_time_ms\x18\x04 \x01(\x01\x12\r\n\x05\x65rror\x18\x05 \x01(\t\"W\n\x17InstallExtensionRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x03 \x01(\t\"K\n\x18InstallExtensionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"=\n\x15ListExtensionsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\"g\n\x16ListExtensionsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12-\n\nextensions\x18\x02 \x03(\x0b\x32\x19.isa.duckdb.ExtensionInfo\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"f\n\rExtensionInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x11\n\tinstalled\x18\x03 \x01(\x08\x12\x0e\n\x06loaded\x18\x04 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\x94\x01\n\x15\x43reateFunctionRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x15\n\rfunction_name\x18\x03 \x01(\t\x12\x15\n\rfunction_body\x18\x04 \x01(\t\x12\x12\n\nparameters\x18\x05 \x03(\t\x12\x13\n\x0breturn_type\x18\x06 \x01(\t\"I\n\x16\x43reateFunctionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\";\n\x12HealthCheckRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65tailed\x18\x02 \x01(\x08\"\xaf\x01\n\x13HealthCheckResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x0e\n\x06status\x18\x03 \x01(\t\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x07\x64\x65tails\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x65rror\x18\x06 \x01(\t\"(\n\x11GetMetricsRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\"\xd6\x01\n\x12GetMetricsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x15\n\rtotal_queries\x18\x02 \x01(\x03\x12\x1a\n\x12\x61\x63tive_connections\x18\x03 \x01(\x03\x12\x19\n\x11\x61vg_query_time_ms\x18\x04 \x01(\x01\x12\x12\n\ncache_hits\x18\x05 \x01(\x03\x12\x14\n\x0c\x63\x61\x63he_misses\x18\x06 \x01(\x03\x12(\n\x07metrics\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x65rror\x18\x08 \x01(\t*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00\x32\xdf\x12\n\rDuckDBService\x12W\n\x0e\x43reateDatabase\x12!.isa.duckdb.CreateDatabaseRequest\x1a\".isa.duckdb.CreateDatabaseResponse\x12T\n\rListDatabases\x12 .isa.duckdb.ListDatabasesRequest\x1a!.isa.duckdb.ListDatabasesResponse\x12W\n\x0e\x44\x65leteDatabase\x12!.isa.duckdb.DeleteDatabaseRequest\x1a\".isa.duckdb.DeleteDatabaseResponse\x12Z\n\x0fGetDatabaseInfo\x12\".isa.duckdb.GetDatabaseInfoRequest\x1a#.isa.duckdb.GetDatabaseInfoResponse\x12W\n\x0e\x42\x61\x63kupDatabase\x12!.isa.duckdb.BackupDatabaseRequest\x1a\".isa.duckdb.BackupDatabaseResponse\x12Z\n\x0fRestoreDatabase\x12\".isa.duckdb.RestoreDatabaseRequest\x1a#.isa.duckdb.RestoreDatabaseResponse\x12Q\n\x0c\x45xecuteQuery\x12\x1f.isa.duckdb.ExecuteQueryRequest\x1a .isa.duckdb.ExecuteQueryResponse\x12U\n\x12\x45xecuteQueryStream\x12\x1f.isa.duckdb.ExecuteQueryRequest\x1a\x1c.isa.duckdb.QueryResultChunk0\x01\x12]\n\x10\x45xecuteStatement\x12#.isa.duckdb.ExecuteStatementRequest\x1a$.isa.duckdb.ExecuteStatementResponse\x12Q\n\x0c\x45xecuteBatch\x12\x1f.isa.duckdb.ExecuteBatchRequest\x1a .isa.duckdb.ExecuteBatchResponse\x12]\n\x10PrepareStatement\x12#.isa.duckdb.PrepareStatementRequest\x1a$.isa.duckdb.PrepareStatementResponse\x12N\n\x0b\x43reateTable\x12\x1e.isa.duckdb.CreateTableRequest\x1a\x1f.isa.duckdb.CreateTableResponse\x12K\n\nListTables\x12\x1d.isa.duckdb.ListTablesRequest\x1a\x1e.isa.duckdb.ListTablesResponse\x12H\n\tDropTable\x12\x1c.isa.duckdb.DropTableRequest\x1a\x1d.isa.duckdb.DropTableResponse\x12W\n\x0eGetTableSchema\x12!.isa.duckdb.GetTableSchemaRequest\x1a\".isa.duckdb.GetTableSchemaResponse\x12T\n\rGetTableStats\x12 .isa.duckdb.GetTableStatsRequest\x1a!.isa.duckdb.GetTableStatsResponse\x12K\n\nCreateView\x12\x1d.isa.duckdb.CreateViewRequest\x1a\x1e.isa.duckdb.CreateViewResponse\x12H\n\tListViews\x12\x1c.isa.duckdb.ListViewsRequest\x1a\x1d.isa.duckdb.ListViewsResponse\x12\x45\n\x08\x44ropView\x12\x1b.isa.duckdb.DropViewRequest\x1a\x1c.isa.duckdb.DropViewResponse\x12Z\n\x0fImportFromMinIO\x12\".isa.duckdb.ImportFromMinIORequest\x1a#.isa.duckdb.ImportFromMinIOResponse\x12T\n\rExportToMinIO\x12 .isa.duckdb.ExportToMinIORequest\x1a!.isa.duckdb.ExportToMinIOResponse\x12W\n\x0eQueryMinIOFile\x12!.isa.duckdb.QueryMinIOFileRequest\x1a\".isa.duckdb.QueryMinIOFileResponse\x12M\n\nImportData\x12\x1d.isa.duckdb.ImportDataRequest\x1a\x1e.isa.duckdb.ImportDataResponse(\x01\x12]\n\x10InstallExtension\x12#.isa.duckdb.InstallExtensionRequest\x1a$.isa.duckdb.InstallExtensionResponse\x12W\n\x0eListExtensions\x12!.isa.duckdb.ListExtensionsRequest\x1a\".isa.duckdb.ListExtensionsResponse\x12W\n\x0e\x43reateFunction\x12!.isa.duckdb.CreateFunctionRequest\x1a\".isa.duckdb.CreateFunctionResponse\x12N\n\x0bHealthCheck\x12\x1e.isa.duckdb.HealthCheckRequest\x1a\x1f.isa.duckdb.HealthCheckResponse\x12K\n\nGetMetrics\x12\x1d.isa.duckdb.GetMetricsRequest\x1a\x1e.isa.duckdb.GetMetricsResponseB1Z/github.com/isa-cloud/isa_cloud/api/proto/duckdbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'duckdb_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/isa-cloud/isa_cloud/api/proto/duckdb'
  _globals['_DATABASEINFO_METADATAENTRY']._loaded_options = None
  _globals['_DATABASEINFO_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._loaded_options = None
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._loaded_options = None
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._loaded_options = None
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_NULLVALUE']._serialized_start=8937
  _globals['_NULLVALUE']._serialized_end=8964
  _globals['_DATABASEINFO']._serialized_start=114
  _globals['_DATABASEINFO']._serialized_end=520
  _globals['_DATABASEINFO_METADATAENTRY']._serialized_start=473
  _globals['_DATABASEINFO_METADATAENTRY']._serialized_end=520
  _globals['_TABLEINFO']._serialized_start=523
  _globals['_TABLEINFO']._serialized_end=740
  _globals['_COLUMNINFO']._serialized_start=743
  _globals['_COLUMNINFO']._serialized_end=889
  _globals['_QUERYRESULTCHUNK']._serialized_start=892
  _globals['_QUERYRESULTCHUNK']._serialized_end=1056
  _globals['_ROW']._serialized_start=1058
  _globals['_ROW']._serialized_end=1098
  _globals['_VALUE']._serialized_start=1101
  _globals['_VALUE']._serialized_end=1380
  _globals['_TABLESTATS']._serialized_start=1382
  _globals['_TABLESTATS']._serialized_end=1500
  _globals['_COLUMNSTATS']._serialized_start=1503
  _globals['_COLUMNSTATS']._serialized_end=1657
  _globals['_CREATEDATABASEREQUEST']._serialized_start=1660
  _globals['_CREATEDATABASEREQUEST']._serialized_end=1996
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._serialized_start=473
  _globals['_CREATEDATABASEREQUEST_METADATAENTRY']._serialized_end=520
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._serialized_start=1951
  _globals['_CREATEDATABASEREQUEST_CONFIGENTRY']._serialized_end=1996
  _globals['_CREATEDATABASERESPONSE']._serialized_start=1998
  _globals['_CREATEDATABASERESPONSE']._serialized_end=2120
  _globals['_LISTDATABASESREQUEST']._serialized_start=2122
  _globals['_LISTDATABASESREQUEST']._serialized_end=2240
  _globals['_LISTDATABASESRESPONSE']._serialized_start=2243
  _globals['_LISTDATABASESRESPONSE']._serialized_end=2397
  _globals['_DELETEDATABASEREQUEST']._serialized_start=2399
  _globals['_DELETEDATABASEREQUEST']._serialized_end=2502
  _globals['_DELETEDATABASERESPONSE']._serialized_start=2504
  _globals['_DELETEDATABASERESPONSE']._serialized_end=2577
  _globals['_GETDATABASEINFOREQUEST']._serialized_start=2579
  _globals['_GETDATABASEINFOREQUEST']._serialized_end=2641
  _globals['_GETDATABASEINFORESPONSE']._serialized_start=2643
  _globals['_GETDATABASEINFORESPONSE']._serialized_end=2749
  _globals['_BACKUPDATABASEREQUEST']._serialized_start=2751
  _globals['_BACKUPDATABASEREQUEST']._serialized_end=2854
  _globals['_BACKUPDATABASERESPONSE']._serialized_start=2857
  _globals['_BACKUPDATABASERESPONSE']._serialized_end=3021
  _globals['_RESTOREDATABASEREQUEST']._serialized_start=3023
  _globals['_RESTOREDATABASEREQUEST']._serialized_end=3112
  _globals['_RESTOREDATABASERESPONSE']._serialized_start=3114
  _globals['_RESTOREDATABASERESPONSE']._serialized_end=3237
  _globals['_EXECUTEQUERYREQUEST']._serialized_start=3240
  _globals['_EXECUTEQUERYREQUEST']._serialized_end=3513
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._serialized_start=3445
  _globals['_EXECUTEQUERYREQUEST_PARAMETERSENTRY']._serialized_end=3513
  _globals['_EXECUTEQUERYRESPONSE']._serialized_start=3516
  _globals['_EXECUTEQUERYRESPONSE']._serialized_end=3706
  _globals['_EXECUTESTATEMENTREQUEST']._serialized_start=3709
  _globals['_EXECUTESTATEMENTREQUEST']._serialized_end=3934
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._serialized_start=3445
  _globals['_EXECUTESTATEMENTREQUEST_PARAMETERSENTRY']._serialized_end=3513
  _globals['_EXECUTESTATEMENTRESPONSE']._serialized_start=3936
  _globals['_EXECUTESTATEMENTRESPONSE']._serialized_end=4061
  _globals['_EXECUTEBATCHREQUEST']._serialized_start=4063
  _globals['_EXECUTEBATCHREQUEST']._serialized_end=4163
  _globals['_EXECUTEBATCHRESPONSE']._serialized_start=4166
  _globals['_EXECUTEBATCHRESPONSE']._serialized_end=4295
  _globals['_BATCHRESULT']._serialized_start=4297
  _globals['_BATCHRESULT']._serialized_end=4365
  _globals['_PREPARESTATEMENTREQUEST']._serialized_start=4367
  _globals['_PREPARESTATEMENTREQUEST']._serialized_end=4449
  _globals['_PREPARESTATEMENTRESPONSE']._serialized_start=4451
  _globals['_PREPARESTATEMENTRESPONSE']._serialized_end=4556
  _globals['_CREATETABLEREQUEST']._serialized_start=4559
  _globals['_CREATETABLEREQUEST']._serialized_end=4740
  _globals['_CREATETABLERESPONSE']._serialized_start=4742
  _globals['_CREATETABLERESPONSE']._serialized_end=4855
  _globals['_LISTTABLESREQUEST']._serialized_start=4857
  _globals['_LISTTABLESREQUEST']._serialized_end=4956
  _globals['_LISTTABLESRESPONSE']._serialized_start=4958
  _globals['_LISTTABLESRESPONSE']._serialized_end=5070
  _globals['_DROPTABLEREQUEST']._serialized_start=5072
  _globals['_DROPTABLEREQUEST']._serialized_end=5184
  _globals['_DROPTABLERESPONSE']._serialized_start=5186
  _globals['_DROPTABLERESPONSE']._serialized_end=5254
  _globals['_GETTABLESCHEMAREQUEST']._serialized_start=5256
  _globals['_GETTABLESCHEMAREQUEST']._serialized_end=5337
  _globals['_GETTABLESCHEMARESPONSE']._serialized_start=5339
  _globals['_GETTABLESCHEMARESPONSE']._serialized_end=5438
  _globals['_GETTABLESTATSREQUEST']._serialized_start=5440
  _globals['_GETTABLESTATSREQUEST']._serialized_end=5545
  _globals['_GETTABLESTATSRESPONSE']._serialized_start=5547
  _globals['_GETTABLESTATSRESPONSE']._serialized_end=5641
  _globals['_CREATEVIEWREQUEST']._serialized_start=5643
  _globals['_CREATEVIEWREQUEST']._serialized_end=5751
  _globals['_CREATEVIEWRESPONSE']._serialized_start=5753
  _globals['_CREATEVIEWRESPONSE']._serialized_end=5822
  _globals['_LISTVIEWSREQUEST']._serialized_start=5824
  _globals['_LISTVIEWSREQUEST']._serialized_end=5880
  _globals['_LISTVIEWSRESPONSE']._serialized_start=5882
  _globals['_LISTVIEWSRESPONSE']._serialized_end=5948
  _globals['_DROPVIEWREQUEST']._serialized_start=5950
  _globals['_DROPVIEWREQUEST']._serialized_end=6024
  _globals['_DROPVIEWRESPONSE']._serialized_start=6026
  _globals['_DROPVIEWRESPONSE']._serialized_end=6093
  _globals['_IMPORTFROMMINIOREQUEST']._serialized_start=6096
  _globals['_IMPORTFROMMINIOREQUEST']._serialized_end=6389
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._serialized_start=6343
  _globals['_IMPORTFROMMINIOREQUEST_OPTIONSENTRY']._serialized_end=6389
  _globals['_IMPORTFROMMINIORESPONSE']._serialized_start=6391
  _globals['_IMPORTFROMMINIORESPONSE']._serialized_end=6515
  _globals['_EXPORTTOMINIOREQUEST']._serialized_start=6518
  _globals['_EXPORTTOMINIOREQUEST']._serialized_end=6781
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._serialized_start=6343
  _globals['_EXPORTTOMINIOREQUEST_OPTIONSENTRY']._serialized_end=6389
  _globals['_EXPORTTOMINIORESPONSE']._serialized_start=6784
  _globals['_EXPORTTOMINIORESPONSE']._serialized_end=6925
  _globals['_QUERYMINIOFILEREQUEST']._serialized_start=6928
  _globals['_QUERYMINIOFILEREQUEST']._serialized_end=7174
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._serialized_start=6343
  _globals['_QUERYMINIOFILEREQUEST_OPTIONSENTRY']._serialized_end=6389
  _globals['_QUERYMINIOFILERESPONSE']._serialized_start=7177
  _globals['_QUERYMINIOFILERESPONSE']._serialized_end=7327
  _globals['_IMPORTDATAREQUEST']._serialized_start=7329
  _globals['_IMPORTDATAREQUEST']._serialized_end=7425
  _globals['_IMPORTDATAMETADATA']._serialized_start=7428
  _globals['_IMPORTDATAMETADATA']._serialized_end=7652
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._serialized_start=6343
  _globals['_IMPORTDATAMETADATA_OPTIONSENTRY']._serialized_end=6389
  _globals['_IMPORTDATARESPONSE']._serialized_start=7654
  _globals['_IMPORTDATARESPONSE']._serialized_end=7773
  _globals['_INSTALLEXTENSIONREQUEST']._serialized_start=7775
  _globals['_INSTALLEXTENSIONREQUEST']._serialized_end=7862
  _globals['_INSTALLEXTENSIONRESPONSE']._serialized_start=7864
  _globals['_INSTALLEXTENSIONRESPONSE']._serialized_end=7939
  _globals['_LISTEXTENSIONSREQUEST']._serialized_start=7941
  _globals['_LISTEXTENSIONSREQUEST']._serialized_end=8002
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_start=8004
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_end=8107
  _globals['_EXTENSIONINFO']._serialized_start=8109
  _globals['_EXTENSIONINFO']._serialized_end=8211
  _globals['_CREATEFUNCTIONREQUEST']._serialized_start=8214
  _globals['_CREATEFUNCTIONREQUEST']._serialized_end=8362
  _globals['_CREATEFUNCTIONRESPONSE']._serialized_start=8364
  _globals['_CREATEFUNCTIONRESPONSE']._serialized_end=8437
  _globals['_HEALTHCHECKREQUEST']._serialized_start=8439
  _globals['_HEALTHCHECKREQUEST']._serialized_end=8498
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=8501
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=8676
  _globals['_GETMETRICSREQUEST']._serialized_start=8678
  _globals['_GETMETRICSREQUEST']._serialized_end=8718
  _globals['_GETMETRICSRESPONSE']._serialized_start=8721
  _globals['_GETMETRICSRESPONSE']._serialized_end=8935
  _globals['_DUCKDBSERVICE']._serialized_start=8967
  _globals['_DUCKDBSERVICE']._serialized_end=11366
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import redis_service_pb2 as redis__service__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in redis_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class RedisServiceStub(object):
    """========================================
    Redis 缓存服务
    ========================================
    这是一个统一的缓存服务，为所有后端服务提供缓存和会话管理能力
    支持：
    - 用户和组织级别的命名空间隔离
    - String、Hash、List、Set、Sorted Set 操作
    - 分布式锁
    - Pub/Sub 消息
    - 过期时间管理
    - 批量操作

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Set = channel.unary_unary(
                '/isa.redis.RedisService/Set',
                request_serializer=redis__service__pb2.SetRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SetResponse.FromString,
                _registered_method=True)
        self.Get = channel.unary_unary(
                '/isa.redis.RedisService/Get',
                request_serializer=redis__service__pb2.GetRequest.SerializeToString,
                response_deserializer=redis__service__pb2.GetResponse.FromString,
                _registered_method=True)
        self.GetMultiple = channel.unary_unary(
                '/isa.redis.RedisService/GetMultiple',
                request_serializer=redis__service__pb2.GetMultipleRequest.SerializeToString,
                response_deserializer=redis__service__pb2.GetMultipleResponse.FromString,
                _registered_method=True)
        self.SetWithExpiration = channel.unary_unary(
                '/isa.redis.RedisService/SetWithExpiration',
                request_serializer=redis__service__pb2.SetWithExpirationRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SetResponse.FromString,
                _registered_method=True)
        self.Increment = channel.unary_unary(
                '/isa.redis.RedisService/Increment',
                request_serializer=redis__service__pb2.IncrementRequest.SerializeToString,
                response_deserializer=redis__service__pb2.IncrementResponse.FromString,
                _registered_method=True)
        self.Decrement = channel.unary_unary(
                '/isa.redis.RedisService/Decrement',
                request_serializer=redis__service__pb2.DecrementRequest.SerializeToString,
                response_deserializer=redis__service__pb2.DecrementResponse.FromString,
                _registered_method=True)
        self.Append = channel.unary_unary(
                '/isa.redis.RedisService/Append',
                request_serializer=redis__service__pb2.AppendRequest.SerializeToString,
                response_deserializer=redis__service__pb2.AppendResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/isa.redis.RedisService/Delete',
                request_serializer=redis__service__pb2.DeleteRequest.SerializeToString,
                response_deserializer=redis__service__pb2.DeleteResponse.FromString,
                _registered_method=True)
        self.DeleteMultiple = channel.unary_unary(
                '/isa.redis.RedisService/DeleteMultiple',
                request_serializer=redis__service__pb2.DeleteMultipleRequest.SerializeToString,
                response_deserializer=redis__service__pb2.DeleteResponse.FromString,
                _registered_method=True)
        self.Exists = channel.unary_unary(
                '/isa.redis.RedisService/Exists',
                request_serializer=redis__service__pb2.ExistsRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ExistsResponse.FromString,
                _registered_method=True)
        self.Expire = channel.unary_unary(
                '/isa.redis.RedisService/Expire',
                request_serializer=redis__service__pb2.ExpireRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ExpireResponse.FromString,
                _registered_method=True)
        self.GetTTL = channel.unary_unary(
                '/isa.redis.RedisService/GetTTL',
                request_serializer=redis__service__pb2.GetTTLRequest.SerializeToString,
                response_deserializer=redis__service__pb2.GetTTLResponse.FromString,
                _registered_method=True)
        self.Rename = channel.unary_unary(
                '/isa.redis.RedisService/Rename',
                request_serializer=redis__service__pb2.RenameRequest.SerializeToString,
                response_deserializer=redis__service__pb2.RenameResponse.FromString,
                _registered_method=True)
        self.ListKeys = channel.unary_unary(
                '/isa.redis.RedisService/ListKeys',
                request_serializer=redis__service__pb2.ListKeysRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ListKeysResponse.FromString,
                _registered_method=True)
        self.HSet = channel.unary_unary(
                '/isa.redis.RedisService/HSet',
                request_serializer=redis__service__pb2.HSetRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HSetResponse.FromString,
                _registered_method=True)
        self.HGet = channel.unary_unary(
                '/isa.redis.RedisService/HGet',
                request_serializer=redis__service__pb2.HGetRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HGetResponse.FromString,
                _registered_method=True)
        self.HGetAll = channel.unary_unary(
                '/isa.redis.RedisService/HGetAll',
                request_serializer=redis__service__pb2.HGetAllRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HGetAllResponse.FromString,
                _registered_method=True)
        self.HDelete = channel.unary_unary(
                '/isa.redis.RedisService/HDelete',
                request_serializer=redis__service__pb2.HDeleteRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HDeleteResponse.FromString,
                _registered_method=True)
        self.HExists = channel.unary_unary(
                '/isa.redis.RedisService/HExists',
                request_serializer=redis__service__pb2.HExistsRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HExistsResponse.FromString,
                _registered_method=True)
        self.HKeys = channel.unary_unary(
                '/isa.redis.RedisService/HKeys',
                request_serializer=redis__service__pb2.HKeysRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HKeysResponse.FromString,
                _registered_method=True)
        self.HValues = channel.unary_unary(
                '/isa.redis.RedisService/HValues',
                request_serializer=redis__service__pb2.HValuesRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HValuesResponse.FromString,
                _registered_method=True)
        self.HIncrement = channel.unary_unary(
                '/isa.redis.RedisService/HIncrement',
                request_serializer=redis__service__pb2.HIncrementRequest.SerializeToString,
                response_deserializer=redis__service__pb2.HIncrementResponse.FromString,
                _registered_method=True)
        self.LPush = channel.unary_unary(
                '/isa.redis.RedisService/LPush',
                request_serializer=redis__service__pb2.LPushRequest.SerializeToString,
                response_deserializer=redis__service__pb2.LPushResponse.FromString,
                _registered_method=True)
        self.RPush = channel.unary_unary(
                '/isa.redis.RedisService/RPush',
                request_serializer=redis__service__pb2.RPushRequest.SerializeToString,
                response_deserializer=redis__service__pb2.RPushResponse.FromString,
                _registered_method=True)
        self.LPop = channel.unary_unary(
                '/isa.redis.RedisService/LPop',
                request_serializer=redis__service__pb2.LPopRequest.SerializeToString,
                response_deserializer=redis__service__pb2.LPopResponse.FromString,
                _registered_method=True)
        self.RPop = channel.unary_unary(
                '/isa.redis.RedisService/RPop',
                request_serializer=redis__service__pb2.RPopRequest.SerializeToString,
                response_deserializer=redis__service__pb2.RPopResponse.FromString,
                _registered_method=True)
        self.LRange = channel.unary_unary(
                '/isa.redis.RedisService/LRange',
                request_serializer=redis__service__pb2.LRangeRequest.SerializeToString,
                response_deserializer=redis__service__pb2.LRangeResponse.FromString,
                _registered_method=True)
        self.LLen = channel.unary_unary(
                '/isa.redis.RedisService/LLen',
                request_serializer=redis__service__pb2.LLenRequest.SerializeToString,
                response_deserializer=redis__service__pb2.LLenResponse.FromString,
                _registered_method=True)
        self.LIndex = channel.unary_unary(
                '/isa.redis.RedisService/LIndex',
                request_serializer=redis__service__pb2.LIndexRequest.SerializeToString,
                response_deserializer=redis__service__pb2.LIndexResponse.FromString,
                _registered_method=True)
        self.LTrim = channel.unary_unary(
                '/isa.redis.RedisService/LTrim',
                request_serializer=redis__service__pb2.LTrimRequest.SerializeToString,
                response_deserializer=redis__service__pb2.LTrimResponse.FromString,
                _registered_method=True)
        self.SAdd = channel.unary_unary(
                '/isa.redis.RedisService/SAdd',
                request_serializer=redis__service__pb2.SAddRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SAddResponse.FromString,
                _registered_method=True)
        self.SRemove = channel.unary_unary(
                '/isa.redis.RedisService/SRemove',
                request_serializer=redis__service__pb2.SRemoveRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SRemoveResponse.FromString,
                _registered_method=True)
        self.SMembers = channel.unary_unary(
                '/isa.redis.RedisService/SMembers',
                request_serializer=redis__service__pb2.SMembersRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SMembersResponse.FromString,
                _registered_method=True)
        self.SIsMember = channel.unary_unary(
                '/isa.redis.RedisService/SIsMember',
                request_serializer=redis__service__pb2.SIsMemberRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SIsMemberResponse.FromString,
                _registered_method=True)
        self.SCard = channel.unary_unary(
                '/isa.redis.RedisService/SCard',
                request_serializer=redis__service__pb2.SCardRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SCardResponse.FromString,
                _registered_method=True)
        self.SUnion = channel.unary_unary(
                '/isa.redis.RedisService/SUnion',
                request_serializer=redis__service__pb2.SUnionRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SUnionResponse.FromString,
                _registered_method=True)
        self.SInter = channel.unary_unary(
                '/isa.redis.RedisService/SInter',
                request_serializer=redis__service__pb2.SInterRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SInterResponse.FromString,
                _registered_method=True)
        self.SDiff = channel.unary_unary(
                '/isa.redis.RedisService/SDiff',
                request_serializer=redis__service__pb2.SDiffRequest.SerializeToString,
                response_deserializer=redis__service__pb2.SDiffResponse.FromString,
                _registered_method=True)
        self.ZAdd = channel.unary_unary(
                '/isa.redis.RedisService/ZAdd',
                request_serializer=redis__service__pb2.ZAddRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZAddResponse.FromString,
                _registered_method=True)
        self.ZRemove = channel.unary_unary(
                '/isa.redis.RedisService/ZRemove',
                request_serializer=redis__service__pb2.ZRemoveRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZRemoveResponse.FromString,
                _registered_method=True)
        self.ZRange = channel.unary_unary(
                '/isa.redis.RedisService/ZRange',
                request_serializer=redis__service__pb2.ZRangeRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZRangeResponse.FromString,
                _registered_method=True)
        self.ZRangeByScore = channel.unary_unary(
                '/isa.redis.RedisService/ZRangeByScore',
                request_serializer=redis__service__pb2.ZRangeByScoreRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZRangeByScoreResponse.FromString,
                _registered_method=True)
        self.ZRank = channel.unary_unary(
                '/isa.redis.RedisService/ZRank',
                request_serializer=redis__service__pb2.ZRankRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZRankResponse.FromString,
                _registered_method=True)
        self.ZScore = channel.unary_unary(
                '/isa.redis.RedisService/ZScore',
                request_serializer=redis__service__pb2.ZScoreRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZScoreResponse.FromString,
                _registered_method=True)
        self.ZCard = channel.unary_unary(
                '/isa.redis.RedisService/ZCard',
                request_serializer=redis__service__pb2.ZCardRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZCardResponse.FromString,
                _registered_method=True)
        self.ZIncrement = channel.unary_unary(
                '/isa.redis.RedisService/ZIncrement',
                request_serializer=redis__service__pb2.ZIncrementRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ZIncrementResponse.FromString,
                _registered_method=True)
        self.AcquireLock = channel.unary_unary(
                '/isa.redis.RedisService/AcquireLock',
                request_serializer=redis__service__pb2.AcquireLockRequest.SerializeToString,
                response_deserializer=redis__service__pb2.AcquireLockResponse.FromString,
                _registered_method=True)
        self.ReleaseLock = channel.unary_unary(
                '/isa.redis.RedisService/ReleaseLock',
                request_serializer=redis__service__pb2.ReleaseLockRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ReleaseLockResponse.FromString,
                _registered_method=True)
        self.RenewLock = channel.unary_unary(
                '/isa.redis.RedisService/RenewLock',
                request_serializer=redis__service__pb2.RenewLockRequest.SerializeToString,
                response_deserializer=redis__service__pb2.RenewLockResponse.FromString,
                _registered_method=True)
        self.Publish = channel.unary_unary(
                '/isa.redis.RedisService/Publish',
                request_serializer=redis__service__pb2.PublishRequest.SerializeToString,
                response_deserializer=redis__service__pb2.PublishResponse.FromString,
                _registered_method=True)
        self.Subscribe = channel.unary_stream(
                '/isa.redis.RedisService/Subscribe',
                request_serializer=redis__service__pb2.SubscribeRequest.SerializeToString,
                response_deserializer=redis__service__pb2.MessageResponse.FromString,
                _registered_method=True)
        self.Unsubscribe = channel.unary_unary(
                '/isa.redis.RedisService/Unsubscribe',
                request_serializer=redis__service__pb2.UnsubscribeRequest.SerializeToString,
                response_deserializer=redis__service__pb2.UnsubscribeResponse.FromString,
                _registered_method=True)
        self.ExecuteBatch = channel.unary_unary(
                '/isa.redis.RedisService/ExecuteBatch',
                request_serializer=redis__service__pb2.RedisBatchRequest.SerializeToString,
                response_deserializer=redis__service__pb2.RedisBatchResponse.FromString,
                _registered_method=True)
        self.CreateSession = channel.unary_unary(
                '/isa.redis.RedisService/CreateSession',
                request_serializer=redis__service__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=redis__service__pb2.CreateSessionResponse.FromString,
                _registered_method=True)
        self.GetSession = channel.unary_unary(
                '/isa.redis.RedisService/GetSession',
                request_serializer=redis__service__pb2.GetSessionRequest.SerializeToString,
                response_deserializer=redis__service__pb2.GetSessionResponse.FromString,
                _registered_method=True)
        self.UpdateSession = channel.unary_unary(
                '/isa.redis.RedisService/UpdateSession',
                request_serializer=redis__service__pb2.UpdateSessionRequest.SerializeToString,
                response_deserializer=redis__service__pb2.UpdateSessionResponse.FromString,
                _registered_method=True)
        self.DeleteSession = channel.unary_unary(
                '/isa.redis.RedisService/DeleteSession',
                request_serializer=redis__service__pb2.DeleteSessionRequest.SerializeToString,
                response_deserializer=redis__service__pb2.DeleteSessionResponse.FromString,
                _registered_method=True)
        self.ListSessions = channel.unary_unary(
                '/isa.redis.RedisService/ListSessions',
                request_serializer=redis__service__pb2.ListSessionsRequest.SerializeToString,
                response_deserializer=redis__service__pb2.ListSessionsResponse.FromString,
                _registered_method=True)
        self.GetStatistics = channel.unary_unary(
                '/isa.redis.RedisService/GetStatistics',
                request_serializer=redis__service__pb2.GetStatisticsRequest.SerializeToString,
                response_deserializer=redis__service__pb2.GetStatisticsResponse.FromString,
                _registered_method=True)
        self.GetKeyInfo = channel.unary_unary(
                '/isa.redis.RedisService/GetKeyInfo',
                request_serializer=redis__service__pb2.GetKeyInfoRequest.SerializeToString,
                response_deserializer=redis__service__pb2.GetKeyInfoResponse.FromString,
                _registered_method=True)
        self.HealthCheck = channel.unary_unary(
                '/isa.redis.RedisService/HealthCheck',
                request_serializer=redis__service__pb2.RedisHealthCheckRequest.SerializeToString,
                response_deserializer=redis__service__pb2.RedisHealthCheckResponse.FromString,
                _registered_method=True)


class RedisServiceServicer(object):
    """========================================
    Redis 缓存服务
    ========================================
    这是一个统一的缓存服务，为所有后端服务提供缓存和会话管理能力
    支持：
    - 用户和组织级别的命名空间隔离
    - String、Hash、List、Set、Sorted Set 操作
    - 分布式锁
    - Pub/Sub 消息
    - 过期时间管理
    - 批量操作

    """

    def Set(self, request, context):
        """========== 字符串操作 (String Operations) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMultiple(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetWithExpiration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Increment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Decrement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Append(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """========== 键操作 (Key Operations) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMultiple(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Exists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Expire(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTTL(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Rename(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HSet(self, request, context):
        """========== 哈希操作 (Hash Operations) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HGet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HGetAll(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HExists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HKeys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HValues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HIncrement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LPush(self, request, context):
        """========== 列表操作 (List Operations) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RPush(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LPop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RPop(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LRange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LLen(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LTrim(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SAdd(self, request, context):
        """========== 集合操作 (Set Operations) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SRemove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SIsMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SCard(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SUnion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SInter(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SDiff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZAdd(self, request, context):
        """========== 有序集合操作 (Sorted Set Operations) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZRemove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZRange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZRangeByScore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZRank(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZScore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZCard(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ZIncrement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcquireLock(self, request, context):
        """========== 分布式锁 (Distributed Lock) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReleaseLock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RenewLock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Publish(self, request, context):
        """========== Pub/Sub ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Unsubscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteBatch(self, request, context):
        """========== 批量操作 (Batch Operations) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSession(self, request, context):
        """========== 会话管理 (Session Management) ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSessions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStatistics(self, request, context):
        """========== 统计和监控 ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetKeyInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HealthCheck(self, request, context):
        """========== 健康检查 ==========
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RedisServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Set': grpc.unary_unary_rpc_method_handler(
                    servicer.Set,
                    request_deserializer=redis__service__pb2.SetRequest.FromString,
                    response_serializer=redis__service__pb2.SetResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=redis__service__pb2.GetRequest.FromString,
                    response_serializer=redis__service__pb2.GetResponse.SerializeToString,
            ),
            'GetMultiple': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMultiple,
                    request_deserializer=redis__service__pb2.GetMultipleRequest.FromString,
                    response_serializer=redis__service__pb2.GetMultipleResponse.SerializeToString,
            ),
            'SetWithExpiration': grpc.unary_unary_rpc_method_handler(
                    servicer.SetWithExpiration,
                    request_deserializer=redis__service__pb2.SetWithExpirationRequest.FromString,
                    response_serializer=redis__service__pb2.SetResponse.SerializeToString,
            ),
            'Increment': grpc.unary_unary_rpc_method_handler(
                    servicer.Increment,
                    request_deserializer=redis__service__pb2.IncrementRequest.FromString,
                    response_serializer=redis__service__pb2.IncrementResponse.SerializeToString,
            ),
            'Decrement': grpc.unary_unary_rpc_method_handler(
                    servicer.Decrement,
                    request_deserializer=redis__service__pb2.DecrementRequest.FromString,
                    response_serializer=redis__service__pb2.DecrementResponse.SerializeToString,
            ),
            'Append': grpc.unary_unary_rpc_method_handler(
                    servicer.Append,
                    request_deserializer=redis__service__pb2.AppendRequest.FromString,
                    response_serializer=redis__service__pb2.AppendResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=redis__service__pb2.DeleteRequest.FromString,
                    response_serializer=redis__service__pb2.DeleteResponse.SerializeToString,
            ),
            'DeleteMultiple': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMultiple,
                    request_deserializer=redis__service__pb2.DeleteMultipleRequest.FromString,
                    response_serializer=redis__service__pb2.DeleteResponse.SerializeToString,
            ),
            'Exists': grpc.unary_unary_rpc_method_handler(
                    servicer.Exists,
                    request_deserializer=redis__service__pb2.ExistsRequest.FromString,
                    response_serializer=redis__service__pb2.ExistsResponse.SerializeToString,
            ),
            'Expire': grpc.unary_unary_rpc_method_handler(
                    servicer.Expire,
                    request_deserializer=redis__service__pb2.ExpireRequest.FromString,
                    response_serializer=redis__service__pb2.ExpireResponse.SerializeToString,
            ),
            'GetTTL': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTTL,
                    request_deserializer=redis__service__pb2.GetTTLRequest.FromString,
                    response_serializer=redis__service__pb2.GetTTLResponse.SerializeToString,
            ),
            'Rename': grpc.unary_unary_rpc_method_handler(
                    servicer.Rename,
                    request_deserializer=redis__service__pb2.RenameRequest.FromString,
                    response_serializer=redis__service__pb2.RenameResponse.SerializeToString,
            ),
            'ListKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListKeys,
                    request_deserializer=redis__service__pb2.ListKeysRequest.FromString,
                    response_serializer=redis__service__pb2.ListKeysResponse.SerializeToString,
            ),
            'HSet': grpc.unary_unary_rpc_method_handler(
                    servicer.HSet,
                    request_deserializer=redis__service__pb2.HSetRequest.FromString,
                    response_serializer=redis__service__pb2.HSetResponse.SerializeToString,
            ),
            'HGet': grpc.unary_unary_rpc_method_handler(
                    servicer.HGet,
                    request_deserializer=redis__service__pb2.HGetRequest.FromString,
                    response_serializer=redis__service__pb2.HGetResponse.SerializeToString,
            ),
            'HGetAll': grpc.unary_unary_rpc_method_handler(
                    servicer.HGetAll,
                    request_deserializer=redis__service__pb2.HGetAllRequest.FromString,
                    response_serializer=redis__service__pb2.HGetAllResponse.SerializeToString,
            ),
            'HDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.HDelete,
                    request_deserializer=redis__service__pb2.HDeleteRequest.FromString,
                    response_serializer=redis__service__pb2.HDeleteResponse.SerializeToString,
            ),
            'HExists': grpc.unary_unary_rpc_method_handler(
                    servicer.HExists,
                    request_deserializer=redis__service__pb2.HExistsRequest.FromString,
                    response_serializer=redis__service__pb2.HExistsResponse.SerializeToString,
            ),
            'HKeys': grpc.unary_unary_rpc_method_handler(
                    servicer.HKeys,
                    request_deserializer=redis__service__pb2.HKeysRequest.FromString,
                    response_serializer=redis__service__pb2.HKeysResponse.SerializeToString,
            ),
            'HValues': grpc.unary_unary_rpc_method_handler(
                    servicer.HValues,
                    request_deserializer=redis__service__pb2.HValuesRequest.FromString,
                    response_serializer=redis__service__pb2.HValuesResponse.SerializeToString,
            ),
            'HIncrement': grpc.unary_unary_rpc_method_handler(
                    servicer.HIncrement,
                    request_deserializer=redis__service__pb2.HIncrementRequest.FromString,
                    response_serializer=redis__service__pb2.HIncrementResponse.SerializeToString,
            ),
            'LPush': grpc.unary_unary_rpc_method_handler(
                    servicer.LPush,
                    request_deserializer=redis__service__pb2.LPushRequest.FromString,
                    response_serializer=redis__service__pb2.LPushResponse.SerializeToString,
            ),
            'RPush': grpc.unary_unary_rpc_method_handler(
                    servicer.RPush,
                    request_deserializer=redis__service__pb2.RPushRequest.FromString,
                    response_serializer=redis__service__pb2.RPushResponse.SerializeToString,
            ),
            'LPop': grpc.unary_unary_rpc_method_handler(
                    servicer.LPop,
                    request_deserializer=redis__service__pb2.LPopRequest.FromString,
                    response_serializer=redis__service__pb2.LPopResponse.SerializeToString,
            ),
            'RPop': grpc.unary_unary_rpc_method_handler(
                    servicer.RPop,
                    request_deserializer=redis__service__pb2.RPopRequest.FromString,
                    response_serializer=redis__service__pb2.RPopResponse.SerializeToString,
            ),
            'LRange': grpc.unary_unary_rpc_method_handler(
                    servicer.LRange,
                    request_deserializer=redis__service__pb2.LRangeRequest.FromString,
                    response_serializer=redis__service__pb2.LRangeResponse.SerializeToString,
            ),
            'LLen': grpc.unary_unary_rpc_method_handler(
                    servicer.LLen,
                    request_deserializer=redis__service__pb2.LLenRequest.FromString,
                    response_serializer=redis__service__pb2.LLenResponse.SerializeToString,
            ),
            'LIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.LIndex,
                    request_deserializer=redis__service__pb2.LIndexRequest.FromString,
                    response_serializer=redis__service__pb2.LIndexResponse.SerializeToString,
            ),
            'LTrim': grpc.unary_unary_rpc_method_handler(
                    servicer.LTrim,
                    request_deserializer=redis__service__pb2.LTrimRequest.FromString,
                    response_serializer=redis__service__pb2.LTrimResponse.SerializeToString,
            ),
            'SAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.SAdd,
                    request_deserializer=redis__service__pb2.SAddRequest.FromString,
                    response_serializer=redis__service__pb2.SAddResponse.SerializeToString,
            ),
            'SRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.SRemove,
                    request_deserializer=redis__service__pb2.SRemoveRequest.FromString,
                    response_serializer=redis__service__pb2.SRemoveResponse.SerializeToString,
            ),
            'SMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.SMembers,
                    request_deserializer=redis__service__pb2.SMembersRequest.FromString,
                    response_serializer=redis__service__pb2.SMembersResponse.SerializeToString,
            ),
            'SIsMember': grpc.unary_unary_rpc_method_handler(
                    servicer.SIsMember,
                    request_deserializer=redis__service__pb2.SIsMemberRequest.FromString,
                    response_serializer=redis__service__pb2.SIsMemberResponse.SerializeToString,
            ),
            'SCard': grpc.unary_unary_rpc_method_handler(
                    servicer.SCard,
                    request_deserializer=redis__service__pb2.SCardRequest.FromString,
                    response_serializer=redis__service__pb2.SCardResponse.SerializeToString,
            ),
            'SUnion': grpc.unary_unary_rpc_method_handler(
                    servicer.SUnion,
                    request_deserializer=redis__service__pb2.SUnionRequest.FromString,
                    response_serializer=redis__service__pb2.SUnionResponse.SerializeToString,
            ),
            'SInter': grpc.unary_unary_rpc_method_handler(
                    servicer.SInter,
                    request_deserializer=redis__service__pb2.SInterRequest.FromString,
                    response_serializer=redis__service__pb2.SInterResponse.SerializeToString,
            ),
            'SDiff': grpc.unary_unary_rpc_method_handler(
                    servicer.SDiff,
                    request_deserializer=redis__service__pb2.SDiffRequest.FromString,
                    response_serializer=redis__service__pb2.SDiffResponse.SerializeToString,
            ),
            'ZAdd': grpc.unary_unary_rpc_method_handler(
                    servicer.ZAdd,
                    request_deserializer=redis__service__pb2.ZAddRequest.FromString,
                    response_serializer=redis__service__pb2.ZAddResponse.SerializeToString,
            ),
            'ZRemove': grpc.unary_unary_rpc_method_handler(
                    servicer.ZRemove,
                    request_deserializer=redis__service__pb2.ZRemoveRequest.FromString,
                    response_serializer=redis__service__pb2.ZRemoveResponse.SerializeToString,
            ),
            'ZRange': grpc.unary_unary_rpc_method_handler(
                    servicer.ZRange,
                    request_deserializer=redis__service__pb2.ZRangeRequest.FromString,
                    response_serializer=redis__service__pb2.ZRangeResponse.SerializeToString,
            ),
            'ZRangeByScore': grpc.unary_unary_rpc_method_handler(
                    servicer.ZRangeByScore,
                    request_deserializer=redis__service__pb2.ZRangeByScoreRequest.FromString,
                    response_serializer=redis__service__pb2.ZRangeByScoreResponse.SerializeToString,
            ),
            'ZRank': grpc.unary_unary_rpc_method_handler(
                    servicer.ZRank,
                    request_deserializer=redis__service__pb2.ZRankRequest.FromString,
                    response_serializer=redis__service__pb2.ZRankResponse.SerializeToString,
            ),
            'ZScore': grpc.unary_unary_rpc_method_handler(
                    servicer.ZScore,
                    request_deserializer=redis__service__pb2.ZScoreRequest.FromString,
                    response_serializer=redis__service__pb2.ZScoreResponse.SerializeToString,
            ),
            'ZCard': grpc.unary_unary_rpc_method_handler(
                    servicer.ZCard,
                    request_deserializer=redis__service__pb2.ZCardRequest.FromString,
                    response_serializer=redis__service__pb2.ZCardResponse.SerializeToString,
            ),
            'ZIncrement': grpc.unary_unary_rpc_method_handler(
                    servicer.ZIncrement,
                    request_deserializer=redis__service__pb2.ZIncrementRequest.FromString,
                    response_serializer=redis__service__pb2.ZIncrementResponse.SerializeToString,
            ),
            'AcquireLock': grpc.unary_unary_rpc_method_handler(
                    servicer.AcquireLock,
                    request_deserializer=redis__service__pb2.AcquireLockRequest.FromString,
                    response_serializer=redis__service__pb2.AcquireLockResponse.SerializeToString,
            ),
            'ReleaseLock': grpc.unary_unary_rpc_method_handler(
                    servicer.ReleaseLock,
                    request_deserializer=redis__service__pb2.ReleaseLockRequest.FromString,
                    response_serializer=redis__service__pb2.ReleaseLockResponse.SerializeToString,
            ),
            'RenewLock': grpc.unary_unary_rpc_method_handler(
                    servicer.RenewLock,
                    request_deserializer=redis__service__pb2.RenewLockRequest.FromString,
                    response_serializer=redis__service__pb2.RenewLockResponse.SerializeToString,
            ),
            'Publish': grpc.unary_unary_rpc_method_handler(
                    servicer.Publish,
                    request_deserializer=redis__service__pb2.PublishRequest.FromString,
                    response_serializer=redis__service__pb2.PublishResponse.SerializeToString,
            ),
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=redis__service__pb2.SubscribeRequest.FromString,
                    response_serializer=redis__service__pb2.MessageResponse.SerializeToString,
            ),
            'Unsubscribe': grpc.unary_unary_rpc_method_handler(
                    servicer.Unsubscribe,
                    request_deserializer=redis__service__pb2.UnsubscribeRequest.FromString,
                    response_serializer=redis__service__pb2.UnsubscribeResponse.SerializeToString,
            ),
            'ExecuteBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteBatch,
                    request_deserializer=redis__service__pb2.RedisBatchRequest.FromString,
                    response_serializer=redis__service__pb2.RedisBatchResponse.SerializeToString,
            ),
            'CreateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSession,
                    request_deserializer=redis__service__pb2.CreateSessionRequest.FromString,
                    response_serializer=redis__service__pb2.CreateSessionResponse.SerializeToString,
            ),
            'GetSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSession,
                    request_deserializer=redis__service__pb2.GetSessionRequest.FromString,
                    response_serializer=redis__service__pb2.GetSessionResponse.SerializeToString,
            ),
            'UpdateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSession,
                    request_deserializer=redis__service__pb2.UpdateSessionRequest.FromString,
                    response_serializer=redis__service__pb2.UpdateSessionResponse.SerializeToString,
            ),
            'DeleteSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSession,
                    request_deserializer=redis__service__pb2.DeleteSessionRequest.FromString,
                    response_serializer=redis__service__pb2.DeleteSessionResponse.SerializeToString,
            ),
            'ListSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSessions,
                    request_deserializer=redis__service__pb2.ListSessionsRequest.FromString,
                    response_serializer=redis__service__pb2.ListSessionsResponse.SerializeToString,
            ),
            'GetStatistics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStatistics,
                    request_deserializer=redis__service__pb2.GetStatisticsRequest.FromString,
                    response_serializer=redis__service__pb2.GetStatisticsResponse.SerializeToString,
            ),
            'GetKeyInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetKeyInfo,
                    request_deserializer=redis__service__pb2.GetKeyInfoRequest.FromString,
                    response_serializer=redis__service__pb2.GetKeyInfoResponse.SerializeToString,
            ),
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=redis__service__pb2.RedisHealthCheckRequest.FromString,
                    response_serializer=redis__service__pb2.RedisHealthCheckResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'isa.redis.RedisService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('isa.redis.RedisService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class RedisService(object):
    """========================================
    Redis 缓存服务
    ========================================
    这是一个统一的缓存服务，为所有后端服务提供缓存和会话管理能力
    支持：
    - 用户和组织级别的命名空间隔离
    - String、Hash、List、Set、Sorted Set 操作
    - 分布式锁
    - Pub/Sub 消息
    - 过期时间管理
    - 批量操作

    """

    @staticmethod
    def Set(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Set',
            redis__service__pb2.SetRequest.SerializeToString,
            redis__service__pb2.SetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Get',
            redis__service__pb2.GetRequest.SerializeToString,
            redis__service__pb2.GetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMultiple(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/GetMultiple',
            redis__service__pb2.GetMultipleRequest.SerializeToString,
            redis__service__pb2.GetMultipleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetWithExpiration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SetWithExpiration',
            redis__service__pb2.SetWithExpirationRequest.SerializeToString,
            redis__service__pb2.SetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Increment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Increment',
            redis__service__pb2.IncrementRequest.SerializeToString,
            redis__service__pb2.IncrementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Decrement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Decrement',
            redis__service__pb2.DecrementRequest.SerializeToString,
            redis__service__pb2.DecrementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Append(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Append',
            redis__service__pb2.AppendRequest.SerializeToString,
            redis__service__pb2.AppendResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Delete',
            redis__service__pb2.DeleteRequest.SerializeToString,
            redis__service__pb2.DeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteMultiple(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/DeleteMultiple',
            redis__service__pb2.DeleteMultipleRequest.SerializeToString,
            redis__service__pb2.DeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Exists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Exists',
            redis__service__pb2.ExistsRequest.SerializeToString,
            redis__service__pb2.ExistsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Expire(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Expire',
            redis__service__pb2.ExpireRequest.SerializeToString,
            redis__service__pb2.ExpireResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTTL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/GetTTL',
            redis__service__pb2.GetTTLRequest.SerializeToString,
            redis__service__pb2.GetTTLResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Rename(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Rename',
            redis__service__pb2.RenameRequest.SerializeToString,
            redis__service__pb2.RenameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ListKeys',
            redis__service__pb2.ListKeysRequest.SerializeToString,
            redis__service__pb2.ListKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HSet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HSet',
            redis__service__pb2.HSetRequest.SerializeToString,
            redis__service__pb2.HSetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HGet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HGet',
            redis__service__pb2.HGetRequest.SerializeToString,
            redis__service__pb2.HGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HGetAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HGetAll',
            redis__service__pb2.HGetAllRequest.SerializeToString,
            redis__service__pb2.HGetAllResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HDelete',
            redis__service__pb2.HDeleteRequest.SerializeToString,
            redis__service__pb2.HDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HExists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HExists',
            redis__service__pb2.HExistsRequest.SerializeToString,
            redis__service__pb2.HExistsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HKeys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HKeys',
            redis__service__pb2.HKeysRequest.SerializeToString,
            redis__service__pb2.HKeysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HValues',
            redis__service__pb2.HValuesRequest.SerializeToString,
            redis__service__pb2.HValuesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HIncrement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HIncrement',
            redis__service__pb2.HIncrementRequest.SerializeToString,
            redis__service__pb2.HIncrementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LPush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/LPush',
            redis__service__pb2.LPushRequest.SerializeToString,
            redis__service__pb2.LPushResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RPush(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/RPush',
            redis__service__pb2.RPushRequest.SerializeToString,
            redis__service__pb2.RPushResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LPop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/LPop',
            redis__service__pb2.LPopRequest.SerializeToString,
            redis__service__pb2.LPopResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RPop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/RPop',
            redis__service__pb2.RPopRequest.SerializeToString,
            redis__service__pb2.RPopResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/LRange',
            redis__service__pb2.LRangeRequest.SerializeToString,
            redis__service__pb2.LRangeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LLen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/LLen',
            redis__service__pb2.LLenRequest.SerializeToString,
            redis__service__pb2.LLenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/LIndex',
            redis__service__pb2.LIndexRequest.SerializeToString,
            redis__service__pb2.LIndexResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LTrim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/LTrim',
            redis__service__pb2.LTrimRequest.SerializeToString,
            redis__service__pb2.LTrimResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SAdd',
            redis__service__pb2.SAddRequest.SerializeToString,
            redis__service__pb2.SAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SRemove',
            redis__service__pb2.SRemoveRequest.SerializeToString,
            redis__service__pb2.SRemoveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SMembers',
            redis__service__pb2.SMembersRequest.SerializeToString,
            redis__service__pb2.SMembersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SIsMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SIsMember',
            redis__service__pb2.SIsMemberRequest.SerializeToString,
            redis__service__pb2.SIsMemberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SCard',
            redis__service__pb2.SCardRequest.SerializeToString,
            redis__service__pb2.SCardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SUnion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SUnion',
            redis__service__pb2.SUnionRequest.SerializeToString,
            redis__service__pb2.SUnionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SInter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SInter',
            redis__service__pb2.SInterRequest.SerializeToString,
            redis__service__pb2.SInterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SDiff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/SDiff',
            redis__service__pb2.SDiffRequest.SerializeToString,
            redis__service__pb2.SDiffResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZAdd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZAdd',
            redis__service__pb2.ZAddRequest.SerializeToString,
            redis__service__pb2.ZAddResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZRemove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZRemove',
            redis__service__pb2.ZRemoveRequest.SerializeToString,
            redis__service__pb2.ZRemoveResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZRange',
            redis__service__pb2.ZRangeRequest.SerializeToString,
            redis__service__pb2.ZRangeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZRangeByScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZRangeByScore',
            redis__service__pb2.ZRangeByScoreRequest.SerializeToString,
            redis__service__pb2.ZRangeByScoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZRank(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZRank',
            redis__service__pb2.ZRankRequest.SerializeToString,
            redis__service__pb2.ZRankResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZScore',
            redis__service__pb2.ZScoreRequest.SerializeToString,
            redis__service__pb2.ZScoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZCard',
            redis__service__pb2.ZCardRequest.SerializeToString,
            redis__service__pb2.ZCardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ZIncrement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ZIncrement',
            redis__service__pb2.ZIncrementRequest.SerializeToString,
            redis__service__pb2.ZIncrementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcquireLock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/AcquireLock',
            redis__service__pb2.AcquireLockRequest.SerializeToString,
            redis__service__pb2.AcquireLockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReleaseLock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ReleaseLock',
            redis__service__pb2.ReleaseLockRequest.SerializeToString,
            redis__service__pb2.ReleaseLockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RenewLock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/RenewLock',
            redis__service__pb2.RenewLockRequest.SerializeToString,
            redis__service__pb2.RenewLockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Publish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Publish',
            redis__service__pb2.PublishRequest.SerializeToString,
            redis__service__pb2.PublishResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/isa.redis.RedisService/Subscribe',
            redis__service__pb2.SubscribeRequest.SerializeToString,
            redis__service__pb2.MessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Unsubscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/Unsubscribe',
            redis__service__pb2.UnsubscribeRequest.SerializeToString,
            redis__service__pb2.UnsubscribeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExecuteBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ExecuteBatch',
            redis__service__pb2.RedisBatchRequest.SerializeToString,
            redis__service__pb2.RedisBatchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/CreateSession',
            redis__service__pb2.CreateSessionRequest.SerializeToString,
            redis__service__pb2.CreateSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/GetSession',
            redis__service__pb2.GetSessionRequest.SerializeToString,
            redis__service__pb2.GetSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/UpdateSession',
            redis__service__pb2.UpdateSessionRequest.SerializeToString,
            redis__service__pb2.UpdateSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/DeleteSession',
            redis__service__pb2.DeleteSessionRequest.SerializeToString,
            redis__service__pb2.DeleteSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/ListSessions',
            redis__service__pb2.ListSessionsRequest.SerializeToString,
            redis__service__pb2.ListSessionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStatistics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/GetStatistics',
            redis__service__pb2.GetStatisticsRequest.SerializeToString,
            redis__service__pb2.GetStatisticsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetKeyInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/GetKeyInfo',
            redis__service__pb2.GetKeyInfoRequest.SerializeToString,
            redis__service__pb2.GetKeyInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/isa.redis.RedisService/HealthCheck',
            redis__service__pb2.RedisHealthCheckRequest.SerializeToString,
            redis__service__pb2.RedisHealthCheckResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
